@@ -25,14 +25,14 @@ __all__ = [
 
 def mesh_fast_copy(other):
     subd = SubdMesh()
-    subd.attributes = deepcopy(other.attributes)
-    subd.default_vertex_attributes = deepcopy(other.default_vertex_attributes)
-    subd.default_face_attributes = deepcopy(other.default_face_attributes)
-    subd.default_edge_attributes = deepcopy(other.default_edge_attributes)
+    # subd.attributes = deepcopy(other.attributes)
+    # subd.default_vertex_attributes = deepcopy(other.default_vertex_attributes)
+    # subd.default_face_attributes = deepcopy(other.default_face_attributes)
+    # subd.default_edge_attributes = deepcopy(other.default_edge_attributes)
     subd.vertex = deepcopy(other.vertex)
     subd.face = deepcopy(other.face)
-    subd.edgedata = deepcopy(other.edgedata)
-    subd.facedata = deepcopy(other.facedata)
+    # subd.edgedata = deepcopy(other.edgedata)
+    # subd.facedata = deepcopy(other.facedata)
     subd.halfedge = deepcopy(other.halfedge)
     subd._max_int_key = other._max_int_key
     subd._max_int_fkey = other._max_int_fkey
@@ -41,6 +41,10 @@ def mesh_fast_copy(other):
 
 class SubdMesh(Mesh):
 
+    _add_vertex = Mesh.add_vertex
+    _add_face = Mesh.add_face
+    _insert_vertex = Mesh.insert_vertex
+
     def add_vertex(self, x, y, z):
         key = self._max_int_key = self._max_int_key + 1
 
@@ -65,6 +69,14 @@ class SubdMesh(Mesh):
 
         return fkey
 
+    def insert_vertex(self, fkey):
+        x, y, z = self.face_center(fkey)
+        w = self.add_vertex(x=x, y=y, z=z)
+        for u, v in self.face_halfedges(fkey):
+            self.add_face([u, v, w])
+        del self.face[fkey]
+        return w
+
 
 # distinguish between subd of meshes with and without boundary
 # closed vs. open
@@ -130,21 +142,20 @@ def mesh_subdivide_tri(mesh, k=1):
         A new subdivided mesh.
 
     """
+    cls = type(mesh)
+    subd = mesh_fast_copy(mesh)
     for _ in range(k):
-        subd = mesh.copy()
-        for fkey in mesh.faces():
+        for fkey in list(subd.faces()):
             subd.insert_vertex(fkey)
-        mesh = subd
-    return mesh
+    return cls.from_data(subd.data)
 
 
 def mesh_subdivide_quad(mesh, k=1):
     """Subdivide a mesh such that all faces are quads.
     """
-    # cls = type(mesh)
+    cls = type(mesh)
     for _ in range(k):
-        # subd = mesh_fast_copy(mesh)
-        subd = mesh.copy()
+        subd = mesh_fast_copy(mesh)
         for u, v in list(subd.edges()):
             mesh_split_edge(subd, u, v, allow_boundary=True)
         for fkey in mesh.faces():
@@ -158,9 +169,9 @@ def mesh_subdivide_quad(mesh, k=1):
                 subd.add_face([a, key, d, c])
             del subd.face[fkey]
         mesh = subd
-    # subd = cls()
-    # subd.data = mesh.data
-    return subd
+    subd2 = cls()
+    subd2.data = mesh.data
+    return subd2
 
 
 def mesh_subdivide_corner(mesh, k=1):
@@ -189,36 +200,28 @@ def mesh_subdivide_corner(mesh, k=1):
     meshes.
 
     """
-
+    cls = type(mesh)
     for _ in range(k):
-        subd = mesh.copy()
-
+        subd = mesh_fast_copy(mesh)
         # split every edge
         for u, v in list(subd.edges()):
             mesh_split_edge(subd, u, v, allow_boundary=True)
-
         # create 4 new faces for every old face
         for fkey in mesh.faces():
-
             descendant = {i: j for i, j in subd.face_halfedges(fkey)}
             ancestor = {j: i for i, j in subd.face_halfedges(fkey)}
-
             center = []
-
             for key in mesh.face_vertices(fkey):
                 a = ancestor[key]
                 d = descendant[key]
-
                 subd.add_face([a, key, d])
-
                 center.append(a)
-
             subd.add_face(center)
             del subd.face[fkey]
-
         mesh = subd
-
-    return mesh
+    subd2 = cls()
+    subd2.data = mesh.data
+    return subd2
 
 
 def mesh_subdivide_catmullclark(mesh, k=1, fixed=None):
@@ -249,14 +252,13 @@ def mesh_subdivide_catmullclark(mesh, k=1, fixed=None):
     >>>
 
     """
+    cls = type(mesh)
     if not fixed:
         fixed = []
-
     fixed = set(fixed)
 
     for _ in range(k):
-
-        subd = mesh.copy()
+        subd = mesh_fast_copy(mesh)
 
         # keep track of original connectivity and vertex locations
 
@@ -359,7 +361,9 @@ def mesh_subdivide_catmullclark(mesh, k=1, fixed=None):
 
         mesh = subd
 
-    return mesh
+    subd2 = cls()
+    subd2.data = mesh.data
+    return subd2
 
 
 def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
@@ -385,13 +389,12 @@ def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
 
     fixed = set(fixed)
 
-    # cls = type(mesh)
+    cls = type(mesh)
 
     for _ in range(k):
         old_xyz = {key: mesh.vertex_coordinates(key) for key in mesh.vertices()}
         fkey_old_new = {fkey: {} for fkey in mesh.faces()}
 
-        # subd = cls()
         subd = SubdMesh()
 
         for fkey in mesh.faces():
@@ -464,7 +467,9 @@ def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
 
         mesh = subd
 
-    return mesh
+    subd2 = cls()
+    subd2.data = mesh.data
+    return subd2
 
 
 def trimesh_subdivide_loop(mesh, k=1, fixed=None):
@@ -507,12 +512,14 @@ def trimesh_subdivide_loop(mesh, k=1, fixed=None):
         viewer.show()
 
     """
+    cls = type(mesh)
+
     if not fixed:
         fixed = []
 
     fixed = set(fixed)
 
-    subd = mesh.copy()
+    subd = mesh_fast_copy(mesh)
 
     for _ in range(k):
         key_xyz = {key: subd.vertex_coordinates(key) for key in subd.vertices()}
@@ -599,7 +606,9 @@ def trimesh_subdivide_loop(mesh, k=1, fixed=None):
 
             del subd.face[fkey]
 
-    return subd
+    subd2 = cls()
+    subd2.data = subd.data
+    return subd2
 
 
 # ==============================================================================
@@ -608,21 +617,27 @@ def trimesh_subdivide_loop(mesh, k=1, fixed=None):
 
 if __name__ == "__main__":
 
+    import compas
     from compas.datastructures import Mesh
-    from compas_plotters import MeshPlotter
+    from compas.geometry import Box
+    # from compas_plotters import MeshPlotter
+    from compas_viewers.meshviewer import MeshViewer
+    from compas.utilities import print_profile
 
-    vertices = [
-        [0.5, 0.0, 0.0],
-        [0.0, 1.0, 0.0],
-        [-0.5, 0.0, 0.0]
-    ]
-    faces = [
-        [0, 1, 2]
-    ]
+    mesh = Mesh.from_obj(compas.get('faces.obj'))
+    mesh = Mesh.from_shape(Box.from_corner_corner_height((0.0, 0.0, 0.0), (1.0, 1.0, 0.0), 1.0))
 
-    mesh = Mesh.from_vertices_and_faces(vertices, faces)
-    subd = trimesh_subdivide_loop(mesh, k=3)
+    subdivide = print_profile(mesh_subdivide_tri)
+    # subdivide = print_profile(mesh_subdivide_quad)
+    # subdivide = print_profile(mesh_subdivide_catmullclark)
+    # subdivide = print_profile(mesh_subdivide_corner)
+    # subdivide = print_profile(mesh_subdivide_doosabin)
 
-    plotter = MeshPlotter(subd)
-    plotter.draw_edges()
-    plotter.show()
+    subd = subdivide(mesh, k=6)
+
+    print(subd.number_of_faces())
+
+    viewer = MeshViewer()
+    viewer.mesh = subd
+
+    viewer.show()
