@@ -2,12 +2,9 @@ from __future__ import print_function
 
 import compas
 
-try:
+if compas.IPY:
     from Rhino.UI import MouseCallback
-
-except ImportError:
-    compas.raise_if_ironpython()
-
+else:
     class MouseCallback(object):
         pass
 
@@ -17,18 +14,19 @@ __all__ = ['Mouse']
 
 class Mouse(MouseCallback):
     """"""
+
     def __init__(self, parent=None):
         super(Mouse, self).__init__()
         self.parent = parent
-        self.x  = None  # x-coordinate of 2D point in the viewport
-        self.y  = None  # y-coordinate of 2D point in the viewport
+        self.x = None  # x-coordinate of 2D point in the viewport
+        self.y = None  # y-coordinate of 2D point in the viewport
         self.p1 = None  # start of the frustum line in world coordinates
         self.p2 = None  # end of the frustum line in world coordinates
 
     def OnMouseMove(self, e):
-        line    = e.View.ActiveViewport.ClientToWorld(e.ViewportPoint)
-        self.x  = e.ViewportPoint.X
-        self.y  = e.ViewportPoint.Y
+        line = e.View.ActiveViewport.ClientToWorld(e.ViewportPoint)
+        self.x = e.ViewportPoint.X
+        self.y = e.ViewportPoint.Y
         self.p1 = line.From
         self.p2 = line.To
         e.View.Redraw()
@@ -60,15 +58,15 @@ if __name__ == '__main__':
 
         def __init__(self, points, tol=0.1):
             super(Inspector, self).__init__()
-            self.mouse     = Mouse()
-            self.points    = points
-            self.tol       = tol
-            self.dotcolor  = Color.FromArgb(255, 0, 0)
+            self.mouse = Mouse()
+            self.points = points
+            self.tol = tol
+            self.dotcolor = Color.FromArgb(255, 0, 0)
             self.textcolor = Color.FromArgb(0, 0, 0)
 
         def DrawForeground(self, e):
-            p1  = self.mouse.p1
-            p2  = self.mouse.p2
+            p1 = self.mouse.p1
+            p2 = self.mouse.p2
             for i, p0 in enumerate(self.points):
                 if distance_point_line(p0, (p1, p2)) < self.tol:
                     e.Display.DrawDot(Point3d(*p0), str(i), self.dotcolor, self.textcolor)
