@@ -105,12 +105,12 @@ def create_layers_from_dict(layers):
             except TypeError:
                 attr = {}
             attr = attr or {}
-            color   = attr.get('color', (0, 0, 0))
+            color = attr.get('color', (0, 0, 0))
             visible = attr.get('visible', True)
-            locked  = attr.get('locked', False)
+            locked = attr.get('locked', False)
             if not rs.IsLayer(fullname):
                 rs.AddLayer(fullname, color, visible, locked)
-            if 'layers' in attr :
+            if 'layers' in attr:
                 recurse(attr['layers'], fullname)
     rs.EnableRedraw(False)
     recurse(layers)
@@ -150,7 +150,8 @@ def clear_layers(layers, include_children=True, include_hidden=True):
     rs.EnableRedraw(False)
     to_delete = []
     for name in layers:
-        to_delete += find_objects_on_layer(name, include_hidden, include_children)
+        if rs.IsLayer(name):
+            to_delete += find_objects_on_layer(name, include_hidden, include_children)
     for guid in to_delete:
         obj = find_object(guid)
         if not obj:
@@ -167,6 +168,7 @@ def clear_layers(layers, include_children=True, include_hidden=True):
 
 def delete_layers(layers):
     to_delete = []
+
     def recurse(layers, parent=None):
         for name in layers:
             if not name:
